//+------------------------------------------------------------------+
//| Example of using WinFile.mqh for reading/writing files           |
//| anywhere on the hard disk. WinFile.mqh needs to be present       |
//| in the experts\include directory, and "Allow DLL imports"        |
//| needs to be turned on.                                           |
//|                                                                  |
//| This example is a *script*, which should be put in               |
//| experts\scripts and then compiled                                |
//+------------------------------------------------------------------+


#include <WinFile.mqh>


#property copyright "Copyright  2009 MTIntelligence.com"
#property link      "http://www.mtintelligence.com"




int start()
{
   string strTestFilename = "c:\\test1.txt";

   MessageBox("About to delete " + strTestFilename + " if it already exists...");

   if (!DoesFileExist(strTestFilename))
   {
      MessageBox(strTestFilename + " does not (yet) exist");
   } else {
      if (DeleteFile(strTestFilename)) 
      {
         MessageBox("Successfully deleted " + strTestFilename);
      } else {
         MessageBox("Failed to delete " + strTestFilename);
      }   
   }
   

   MessageBox("About to write some example data to " + strTestFilename + "...");

   // Write some CRLF-terminated lines to the test file 
   int fWrite = OpenNewFileForWriting(strTestFilename, true);
   if (!IsValidFileHandle(fWrite))
   {
      MessageBox("Unable to open " + strTestFilename + " for writing");
   } else {
      WriteToFile(fWrite, "Line 1|");
      WriteToFile(fWrite, "Line 2|");
      WriteToFile(fWrite, "Line 3|");
   }



   MessageBox("About to read data from " + strTestFilename + ", in its entirety and then a second time, line-by-line...");

   // Opens a separate handle for reading from the file - demonstrates
   // shared access. In the call above, the ShareForReading parameter
   // must be set to true, and in this call the ShareForWriting
   // parameter must also be set to true.
   int fRead = OpenExistingFileForReading(strTestFilename, true, true);
   if (!IsValidFileHandle(fRead))
   {
      MessageBox("Unable to open " + strTestFilename + " for reading");
   } else {
      // Read the whole file 
      string strWholeFile = ReadWholeFile(fRead);
   
      MessageBox(strWholeFile, "Full contents of " + strTestFilename);
   }   

   // Move the pointer back to the start of the file 
   if (!MoveToFileStart(fRead))
   {
      MessageBox("Failed to move to start of " + strTestFilename);
   } else {
      
      // Read the file line by line 
      while (!IsFileAtEnd(fRead))
      {
         string strLine = ReadLineFromFile(fRead, "|");
         MessageBox(strLine, "Line from " + strTestFilename);
      }
   }

   // Close the handles to the file    
   CloseFile(fWrite);
   CloseFile(fRead);



   MessageBox("About to write an array of doubles to " + strTestFilename + "...");

   // Re-open the file for writing, this time using the call which assumes that the
   // file already exists. Do *not* append to the file - overwrite it. (And don't
   // allow read access by other callers.)
   int fWriteArray = OpenExistingFileForWriting(strTestFilename, false);
   if (!IsValidFileHandle(fWriteArray))
   {
      MessageBox("Unable to re-open " + strTestFilename);   
   
   } else {
      // Create a simple multi-dimensional array of doubles 
      double ExampleWriteArray[3][2] = {1,2,3,4,5,6};

      // Write the array to the file    
      if (!WriteDoubleArrayToFile(fWriteArray, ExampleWriteArray))
      {
         MessageBox("Unable to write an array of doubles to " + strTestFilename);
      } else {
         MessageBox("Successfully written array of doubles to " + strTestFilename);
      }
   
      CloseFile(fWriteArray);
   }
   


   MessageBox("About to read the array of doubles from " + strTestFilename + "...");

   // Re-open a the file for reading, this time asking for exclusive access - 
   // neither read-sharing nor write-sharing is allowed 
   int fReadArray = OpenExistingFileForReading(strTestFilename, false, false);
   if (!IsValidFileHandle(fReadArray))
   {
      MessageBox("Unable to open " + strTestFilename + " for exclusive access");
   } else {
      
      // Read an array of doubles. The size of the array must be set before
      // reading, and the results are unpredictable if the size does not
      // match what's in the file       
      double ExampleReadArray[3][2];
      
      if (!ReadDoubleArrayFromFile(fReadArray, ExampleReadArray))
      {
         MessageBox("Unable to read the array of doubles from " + strTestFilename);
      } else {

         // Display the list
         string strArray = "{";
         for (int iDim1 = 0; iDim1 < 3; iDim1++)
         {
            for (int iDim2 = 0; iDim2 < 2; iDim2++)
            {
               strArray = strArray + DoubleToStr(ExampleReadArray[iDim1][iDim2], 2) + " ";
            }
         }
         strArray = strArray + "}";
      
         MessageBox(strArray, "Read array from " + strTestFilename);
      }
      
      CloseFile(fReadArray);
   }
}